yakumo.session.Session

Package yakumo :: Module session :: Class Session |
[hide private]
[frames] | no frames]

# Class Session

source code

    object --+
             |
            Session

Instance Methods | [hide private]
__init__(self, config) x.__init__(...) initializes x; see help(type(x)) for signature | source code
has_endpoint(self, service) | source code
get_proxy(self, service) | source code
get_token(self) | source code
make_headers(self, kwargs, content_type=None, accept=`'``application/json``'`) | source code
get(self, *args, **kwargs) | source code
head(self, *args, **kwargs) | source code
delete(self, *args, **kwargs) | source code
patch(self, *args, **kwargs) | source code
post(self, *args, **kwargs) | source code
put(self, *args, **kwargs) | source code
get_raw(self, *args, **kwargs) | source code
post_raw(self, *args, **kwargs) | source code
put_raw(self, *args, **kwargs) | source code
get_file(self, *args, **kwargs) | source code
post_file(self, *args, **kwargs) | source code
put_file(self, *args, **kwargs) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Static Methods | [hide private]
json_body(kwargs) | source code

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, config) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### get(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator` `@safe_json_load`

### head(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator`

### delete(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator`

### patch(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator` `@safe_json_load`

### post(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator` `@safe_json_load`

### put(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator` `@safe_json_load`

### get_raw(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator`

### post_raw(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator` `@safe_json_load`

### put_raw(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator` `@safe_json_load`

### get_file(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator` `@safe_json_load`

### post_file(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator` `@safe_json_load`

### put_file(self, *args, **kwargs) | source code
Decorators: `@reauth` `@exception_translator` `@safe_json_load`